@@ -43,7 +43,7 @@ class PollVoteView(FormView):
         self.form = get_poll_vote_form(poll)
 
         return super(PollVoteView, self).get(request, *args, **kwargs)
-
+        
     def post(self, request, *args, **kwargs):
         ANONYMOUS_VOTING = getattr(
             settings,
@@ -143,7 +143,21 @@ class PollVoteView(FormView):
         context['pk'] = pk
         context['form'] = self.form
         context['instance'] = instance
-
+        
+        message = getattr(
+                settings,
+                'POLL_MESSAGE_VOTE_ERROR_CHOICE_SELECTION',
+                'Select a choice!')
+        
+        context['message1'] = message
+        
+        message = getattr(
+                settings,
+                'POLL_MESSAGE_VOTE_ERROR_ALREADY_VOTED',
+                'You have already voted in this poll!')
+        
+        context['message2'] = message
+        
         return context
 
 
